==> adminer-3.6.1.zip: adminer-3.6.1/adminer/lang/ar.inc.php <==
<?php
$translations = array(
	'Login' => 'تسجيل الدخول',
	'Logout successful.' => 'مع السلامة.',
	'Invalid credentials.' => 'فشل في تسجيل الدخول.',
	'Server' => 'الخادم',
	'Username' => 'المستعمل',
	'Password' => 'كلمة المرور',
	'Select database' => 'إختر قاعدة البيانات',
	'Invalid database.' => 'قاعدة بيانات خاطئة.',
	'Create new database' => 'أنشئ فاعدة بيانات',
	'Table has been dropped.' => 'تم حذف الجدول.',
	'Table has been altered.' => 'تم تعديل الجدول.',
	'Table has been created.' => 'تم إنشاء الجدول.',
	'Alter table' => 'تعديل الجدول',
	'Create table' => 'إنشاء جدول',
	'Table name' => 'إسم الجدول',
	'engine' => 'المحرك',
	'collation' => 'الترتيب',
	'Column name' => 'إسم العمود',
	'Type' => 'النوع',
	'Length' => 'الطول',
	'Auto Increment' => 'تزايد تلقائي',
	'Options' => 'خيارات',
	'Save' => 'حفظ',
	'Drop' => 'حذف',
	'Database has been created.' => 'تم إنشاء قاعدة البيانات.',
	'Database has been renamed.' => 'تمت إعادة تسمية فاعدة البيانات.',
	'Database has been altered.' => 'تم تعديل قاعدة البيانات.',
	'Alter database' => 'تعديل قاعدة البيانات',
	'Create database' => 'إنشاء قاعدة بيانات',
	'SQL command' => 'إستعلام SQL',
	'Dump' => 'تصدير',
	'Logout' => 'تسجيل الخروج',
	'database' => 'قاعدة بيانات',
	'Use' => 'المستعمل',
	'No tables.' => 'لا توجد جداول.',
	'select' => 'تحديد',
	'Create new table' => 'أنشئ جدول جديد',
	'Item has been deleted.' => 'تم حذف العنصر.',
	'Item has been updated.' => 'تم تعديل العنصر.',
	'Edit' => 'تعديل',
	'Insert' => 'إنشاء',
	'Save and insert next' => 'جفظ و إنشاء التالي',
	'Delete' => 'مسح',
	'Database' => 'قاعدة بيانات',
	'Routines' => 'الروتينات',
	'Indexes have been altered.' => 'تم تعديل المؤشر.',
	'Indexes' => 'المؤشرات',
	'Alter indexes' => 'تعديل المؤشرات',
	'Add next' => 'إضافة التالي',
	'Language' => 'اللغة',
	'Select' => 'إختيار',
	'New item' => 'عنصر جديد',
	'Search' => 'بحث',
	'Sort' => 'ترتيب',
	'descending' => 'تنازلي',
	'Limit' => 'حد',
	'No rows.' => 'لا توجد نتائج.',
	'Action' => 'حركة',
	'edit' => 'تعديل',
	'Page' => 'صفحة',
	'Query executed OK, %d row(s) affected.' => 'تم تنفسذ الإستعلام, %d عدد الأسطر المعدلة.',
	'Error in query' => 'هناك خطأ في الإستعلام',
	'Execute' => 'تنفيذ',
	'Table' => 'جدول',
	'Foreign keys' => 'مفاتيح أجنبية',
	'Triggers' => 'الزنادات',
	'View' => 'عرض',
	'Unable to select the table' => 'من غير الممكن إختيار الجدول',
	'Invalid CSRF token. Send the form again.' => 'CSRF Token خاطئ. من فضلك أعد إرسال الإستمارة.',
	'Comment' => 'تعليق',
	'Default values' => 'القيمة الإفتراضية',
	'%d byte(s)' => '%d بايت',
	'No commands to execute.' => 'لا توجد أوامر للتنفيذ.',
	'Unable to upload a file.' => 'من غير الممكن رفع الملف.',
	'File upload' => 'رفع ملف',
	'File uploads are disabled.' => 'تم إلغاء رفع الملفات.',
	'Routine has been called, %d row(s) affected.' => 'تم إستدعاء الروتين, عدد الأسطر المعدلة %d.',
	'Call' => 'إستدعاء',
	'No extension' => 'إمتداد غير موجود',
	'None of the supported PHP extensions (%s) are available.' => 'إمتدادات php المدعومة غير موجودة.',
	'Session support must be enabled.' => 'عليك تفعيل نظام الجلسات.',
	'Session expired, please login again.' => 'إنتهت الجلسة، من فضلك أعد تسجيل الدخول.',
	'Text length' => 'طول النص',
	'Foreign key has been dropped.' => 'المفتاح الأجنبي تم مسحه.',
	'Foreign key has been altered.' => 'المفتاح الأجنبي تم تعديله.',
	'Foreign key has been created.' => 'المفتاح الأجنبي تم إنشاؤه.',
	'Foreign key' => 'مفتاح أجنبي',
	'Target table' => 'الجدول المستهدف',
	'Change' => 'تعديل',
	'Source' => 'المصدر',
	'Target' => 'الهدف',
	'Add column' => 'أضف عمود',
	'Alter' => 'تعديل',
	'Add foreign key' => 'إضافة مفتاح أجنبي',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'نوع المؤشر',
	'Column (length)' => 'العمود (الطول)',
	'View has been dropped.' => 'تم مسح العرض.',
	'View has been altered.' => 'تم تعديل العرض.',
	'View has been created.' => 'تم إنشاء العرض.',
	'Alter view' => 'تعديل عرض',
	'Create view' => 'إنشاء عرض',
	'Name' => 'الإسم',
	'Process list' => 'قائمة الإجراءات',
	'%d process(es) have been killed.' => 'عدد الإجراءات التي تم إيقافها %d.',
	'Kill' => 'إيقاف',
	'Parameter name' => 'إسم المتغير',
	'Database schema' => 'مخطط فاعدة البيانات',
	'Create procedure' => 'إنشاء إجراء',
	'Create function' => 'إنشاء دالة',
	'Routine has been dropped.' => 'تم حذف الروتين.',
	'Routine has been altered.' => 'تم تعديل الروتين.',
	'Routine has been created.' => 'تم إنشاء الروتين.',
	'Alter function' => 'تعديل الدالة',
	'Alter procedure' => 'تعديل الإجراء',
	'Return type' => 'نوع العودة',
	'Add trigger' => 'إضافة زناد',
	'Trigger has been dropped.' => 'تم حذف الزناد.',
	'Trigger has been altered.' => 'تم تعديل الزناد.',
	'Trigger has been created.' => 'تم إنشاء الزناد.',
	'Alter trigger' => 'تعديل زناد',
	'Create trigger' => 'إنشاء زناد',
	'Time' => 'الوقت',
	'Event' => 'الحدث',
	'%d row(s)' => '%d أسطر',
	'Remove' => 'مسح',
	'Are you sure?' => 'هل أنت متأكد؟',
	'Privileges' => 'الإمتيازات',
	'Create user' => 'إنشاء مستخدم',
	'User has been dropped.' => 'تم حذف المستخدم.',
	'User has been altered.' => 'تم تعديل المستخدم.',
	'User has been created.' => 'تم إنشاء المستخدم.',
	'Hashed' => 'تلبيد',
	'Column' => 'عمود',
	'Routine' => 'روتين',
	'Grant' => 'موافق',
	'Revoke' => 'إلغاء',
	'%s version: %s through PHP extension %s' => 'النسخة %s : %s عن طريق إمتداد ال PHP %s',
	'Logged as: %s' => 'تم تسجيل الدخول بإسم %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'معلومات POST كبيرة جدا. قم بتقليص حجم المعلومات أو قم بزيادة قيمة %s في خيارات ال PHP.',
	'Move up' => 'نقل للأعلى',
	'Move down' => 'نقل للأسفل',
	'Export' => 'تصدير',
	'Tables' => 'جداول',
	'Data' => 'معلومات',
	'Output' => 'إخراج',
	'open' => 'فتح',
	'save' => 'حفظ',
	'Format' => 'الصيغة',
	'Functions' => 'الدوال',
	'Aggregation' => 'تجميع',
	'Event has been dropped.' => 'تم مسح الحدث.',
	'Event has been altered.' => 'تم تعديل الحدث.',
	'Event has been created.' => 'تم إنشاء الحدث.',
	'Alter event' => 'تعديل حدث',
	'Create event' => 'إنشاء حدث',
	'Start' => 'إبدأ',
	'End' => 'إنهاء',
	'Every' => 'كل',
	'Status' => 'حالة',
	'On completion preserve' => 'حفظ عند الإنتهاء',
	'Events' => 'الأحداث',
	'Schedule' => 'مواعيد',
	'At given time' => 'في وقت محدد',
	'Save and continue edit' => 'إحفظ و واصل التعديل',
	'original' => 'الأصلي',
	'Tables have been truncated.' => 'تم قطع الجداول.',
	'Tables have been moved.' => 'تم نقل الجداول.',
	'Tables have been dropped.' => 'تم حذف الجداول.',
	'Tables and views' => 'الجداول و العروض',
	'Engine' => 'المحرك',
	'Collation' => 'ترتيب',
	'Data Length' => 'طول المعطيات.',
	'Index Length' => 'طول المؤشر.',
	'Data Free' => 'المساحة الحرة',
	'Rows' => 'الأسطر',
	',' => ',',
	'Analyze' => 'تحليل',
	'Optimize' => 'تحسين',
	'Check' => 'فحص',
	'Repair' => 'إصلاح',
	'Truncate' => 'قطع',
	'Move to other database' => 'نقل إلى قاعدة بيانات أخرى',
	'Move' => 'نقل',
	'%d item(s) have been affected.' => 'عدد العناصر المعدلة هو %d.',
	'whole result' => 'نتيجة كاملة',
	'Clone' => 'نسخ',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'لقد تجاوزت العدد الأقصى للحقول. يرجى الرفع من %s و %s.',
	'Partition by' => 'مقسم بواسطة',
	'Partitions' => 'التقسيمات',
	'Partition name' => 'إسم التقسيم',
	'Values' => 'القيم',
	'%d row(s) have been imported.' => 'عدد الأسطر المستوردة هو %d.',
	'anywhere' => 'في اي مكان',
	'Import' => 'إستيراد',
	'Stop on error' => 'أوقف في حالة حدوث خطأ',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'jj/mm/[aaaa]',
	'History' => 'تاريخ',
	'Variables' => 'متغيرات',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'أعمدة المصدر و الهدف يجب أن تكون بنفس النوع, يجب أن يكون هناك مؤشر في أعمدة الهدف و البيانات المرجعية يجب ان تكون موجودة.',
	'Relations' => 'علاقات',
	'Run file' => 'نفذ الملف',
	'Clear' => 'مسح',
	'Maximum allowed file size is %sB.' => 'حجم الملف الأقصى هو %sB.',
	'Numbers' => 'أعداد',
	'Date and time' => 'التاريخ و الوقت',
	'Strings' => 'سلاسل',
	'Binary' => 'ثنائية',
	'Lists' => 'قوائم',
	'Editor' => 'المحرر',
	'E-mail' => 'البريد الإلكتروني',
	'From' => 'من',
	'Subject' => 'الموضوع',
	'Send' => 'إرسال',
	'%d e-mail(s) have been sent.' => 'تم إرسال %d رسالة.',
	'Webserver file %s' => 'ملف %s من خادم الويب',
	'File does not exist.' => 'الملف غير موجود.',
	'%d in total' => '%d في المجموع',
	'Permanent login' => 'تسجيل دخول دائم',
	'Databases have been dropped.' => 'تم حذف قواعد البيانات.',
	'Database has been dropped.' => 'تم حذف قاعدة البيانات.',
	'Search data in tables' => 'بحث في الجداول',
	'schema' => 'المخطط',
	'Schema' => 'المخطط',
	'Alter schema' => 'تعديل المخطط',
	'Create schema' => 'إنشاء مخطط',
	'Schema has been dropped.' => 'تم حذف المخطط.',
	'Schema has been created.' => 'تم إنشاء المخطط.',
	'Schema has been altered.' => 'تم تعديل المخطط.',
	'Sequences' => 'السلاسل',
	'Create sequence' => 'إنشاء سلسلة',
	'Alter sequence' => 'تعديل سلسلة',
	'Sequence has been dropped.' => 'تم حذف السلسلة.',
	'Sequence has been created.' => 'تم إنشاء السلسلة.',
	'Sequence has been altered.' => 'تم تعديل السلسلة.',
	'User types' => 'نوع المستخدم',
	'Create type' => 'إنشاء نوع',
	'Alter type' => 'تعديل نوع',
	'Type has been dropped.' => 'تم حذف النوع.',
	'Type has been created.' => 'تم إنشاء النوع.',
	'Double click on a value to modify it.' => 'أنقر نقرا مزدوجا على قيمة لتعديلها.',
	'Use edit link to modify this value.' => 'إستعمل الرابط "تعديل" لتعديل هذه القيمة.',
	'last' => 'الأخيرة',
	'From server' => 'من الخادم',
	'System' => 'النظام',
	'Select data' => 'عرض البيانات',
	'Show structure' => 'عرض التركيبة',
	'empty' => 'فارغ',
	'Network' => 'شبكة',
	'Geometry' => 'هندسة',
	'File exists.' => 'الملف موجود.',
	'Attachments' => 'ملفات مرفقة.',
	'Item%s has been inserted.' => 'تم إدراج العنصر.',
	'now' => 'الآن',
	'%d query(s) executed OK.' => array('تم تنفيذ الإستعلام %d بنجاح.', 'تم تنفيذ الإستعلامات %d بنجاح.'),
	'Show only errors' => 'إعرض الأخطاء فقط',
	'Last page' => 'الصفحة السابقة',
	'Refresh' => 'تحديث',
	'Invalid schema.' => 'مخطط خاطئ.',
	'Please use one of the extensions %s.' => 'من فضلك إستعمل إحدى الإمتدادات: %s.',
	'ltr' => 'rtl',
	'Tables have been copied.' => 'تم نسخ الجداول.',
	'Copy' => 'نسخ',
	'Permanent link' => 'وصلة دائمة',
	'Edit all' => 'تعديل الكل',
	'HH:MM:SS' => 'HH:MM:SS',
);

==> adminer-3.7.0.zip: adminer-3.7.0/adminer/lang/ar.inc.php <==
<?php
$translations = array(
	'Login' => 'تسجيل الدخول',
	'Logout successful.' => 'مع السلامة.',
	'Invalid credentials.' => 'فشل في تسجيل الدخول.',
	'Server' => 'الخادم',
	'Username' => 'المستعمل',
	'Password' => 'كلمة المرور',
	'Select database' => 'إختر قاعدة البيانات',
	'Invalid database.' => 'قاعدة بيانات خاطئة.',
	'Create new database' => 'أنشئ فاعدة بيانات',
	'Table has been dropped.' => 'تم حذف الجدول.',
	'Table has been altered.' => 'تم تعديل الجدول.',
	'Table has been created.' => 'تم إنشاء الجدول.',
	'Alter table' => 'تعديل الجدول',
	'Create table' => 'إنشاء جدول',
	'Table name' => 'إسم الجدول',
	'engine' => 'المحرك',
	'collation' => 'الترتيب',
	'Column name' => 'إسم العمود',
	'Type' => 'النوع',
	'Length' => 'الطول',
	'Auto Increment' => 'تزايد تلقائي',
	'Options' => 'خيارات',
	'Save' => 'حفظ',
	'Drop' => 'حذف',
	'Database has been created.' => 'تم إنشاء قاعدة البيانات.',
	'Database has been renamed.' => 'تمت إعادة تسمية فاعدة البيانات.',
	'Database has been altered.' => 'تم تعديل قاعدة البيانات.',
	'Alter database' => 'تعديل قاعدة البيانات',
	'Create database' => 'إنشاء قاعدة بيانات',
	'SQL command' => 'إستعلام SQL',
	'Dump' => 'تصدير',
	'Logout' => 'تسجيل الخروج',
	'database' => 'قاعدة بيانات',
	'Use' => 'المستعمل',
	'No tables.' => 'لا توجد جداول.',
	'select' => 'تحديد',
	'Create new table' => 'أنشئ جدول جديد',
	'Item has been deleted.' => 'تم حذف العنصر.',
	'Item has been updated.' => 'تم تعديل العنصر.',
	'Edit' => 'تعديل',
	'Insert' => 'إنشاء',
	'Save and insert next' => 'جفظ و إنشاء التالي',
	'Delete' => 'مسح',
	'Database' => 'قاعدة بيانات',
	'Routines' => 'الروتينات',
	'Indexes have been altered.' => 'تم تعديل المؤشر.',
	'Indexes' => 'المؤشرات',
	'Alter indexes' => 'تعديل المؤشرات',
	'Add next' => 'إضافة التالي',
	'Language' => 'اللغة',
	'Select' => 'إختيار',
	'New item' => 'عنصر جديد',
	'Search' => 'بحث',
	'Sort' => 'ترتيب',
	'descending' => 'تنازلي',
	'Limit' => 'حد',
	'No rows.' => 'لا توجد نتائج.',
	'Action' => 'حركة',
	'edit' => 'تعديل',
	'Page' => 'صفحة',
	'Query executed OK, %d row(s) affected.' => 'تم تنفسذ الإستعلام, %d عدد الأسطر المعدلة.',
	'Error in query' => 'هناك خطأ في الإستعلام',
	'Execute' => 'تنفيذ',
	'Table' => 'جدول',
	'Foreign keys' => 'مفاتيح أجنبية',
	'Triggers' => 'الزنادات',
	'View' => 'عرض',
	'Unable to select the table' => 'من غير الممكن إختيار الجدول',
	'Invalid CSRF token. Send the form again.' => 'CSRF Token خاطئ. من فضلك أعد إرسال الإستمارة.',
	'Comment' => 'تعليق',
	'Default values' => 'القيمة الإفتراضية',
	'%d byte(s)' => '%d بايت',
	'No commands to execute.' => 'لا توجد أوامر للتنفيذ.',
	'Unable to upload a file.' => 'من غير الممكن رفع الملف.',
	'File upload' => 'رفع ملف',
	'File uploads are disabled.' => 'تم إلغاء رفع الملفات.',
	'Routine has been called, %d row(s) affected.' => 'تم إستدعاء الروتين, عدد الأسطر المعدلة %d.',
	'Call' => 'إستدعاء',
	'No extension' => 'إمتداد غير موجود',
	'None of the supported PHP extensions (%s) are available.' => 'إمتدادات php المدعومة غير موجودة.',
	'Session support must be enabled.' => 'عليك تفعيل نظام الجلسات.',
	'Session expired, please login again.' => 'إنتهت الجلسة، من فضلك أعد تسجيل الدخول.',
	'Text length' => 'طول النص',
	'Foreign key has been dropped.' => 'المفتاح الأجنبي تم مسحه.',
	'Foreign key has been altered.' => 'المفتاح الأجنبي تم تعديله.',
	'Foreign key has been created.' => 'المفتاح الأجنبي تم إنشاؤه.',
	'Foreign key' => 'مفتاح أجنبي',
	'Target table' => 'الجدول المستهدف',
	'Change' => 'تعديل',
	'Source' => 'المصدر',
	'Target' => 'الهدف',
	'Add column' => 'أضف عمود',
	'Alter' => 'تعديل',
	'Add foreign key' => 'إضافة مفتاح أجنبي',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'نوع المؤشر',
	'Column (length)' => 'العمود (الطول)',
	'View has been dropped.' => 'تم مسح العرض.',
	'View has been altered.' => 'تم تعديل العرض.',
	'View has been created.' => 'تم إنشاء العرض.',
	'Alter view' => 'تعديل عرض',
	'Create view' => 'إنشاء عرض',
	'Name' => 'الإسم',
	'Process list' => 'قائمة الإجراءات',
	'%d process(es) have been killed.' => 'عدد الإجراءات التي تم إيقافها %d.',
	'Kill' => 'إيقاف',
	'Parameter name' => 'إسم المتغير',
	'Database schema' => 'مخطط فاعدة البيانات',
	'Create procedure' => 'إنشاء إجراء',
	'Create function' => 'إنشاء دالة',
	'Routine has been dropped.' => 'تم حذف الروتين.',
	'Routine has been altered.' => 'تم تعديل الروتين.',
	'Routine has been created.' => 'تم إنشاء الروتين.',
	'Alter function' => 'تعديل الدالة',
	'Alter procedure' => 'تعديل الإجراء',
	'Return type' => 'نوع العودة',
	'Add trigger' => 'إضافة زناد',
	'Trigger has been dropped.' => 'تم حذف الزناد.',
	'Trigger has been altered.' => 'تم تعديل الزناد.',
	'Trigger has been created.' => 'تم إنشاء الزناد.',
	'Alter trigger' => 'تعديل زناد',
	'Create trigger' => 'إنشاء زناد',
	'Time' => 'الوقت',
	'Event' => 'الحدث',
	'%d row(s)' => '%d أسطر',
	'Remove' => 'مسح',
	'Are you sure?' => 'هل أنت متأكد؟',
	'Privileges' => 'الإمتيازات',
	'Create user' => 'إنشاء مستخدم',
	'User has been dropped.' => 'تم حذف المستخدم.',
	'User has been altered.' => 'تم تعديل المستخدم.',
	'User has been created.' => 'تم إنشاء المستخدم.',
	'Hashed' => 'تلبيد',
	'Column' => 'عمود',
	'Routine' => 'روتين',
	'Grant' => 'موافق',
	'Revoke' => 'إلغاء',
	'%s version: %s through PHP extension %s' => 'النسخة %s : %s عن طريق إمتداد ال PHP %s',
	'Logged as: %s' => 'تم تسجيل الدخول بإسم %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'معلومات POST كبيرة جدا. قم بتقليص حجم المعلومات أو قم بزيادة قيمة %s في خيارات ال PHP.',
	'Move up' => 'نقل للأعلى',
	'Move down' => 'نقل للأسفل',
	'Export' => 'تصدير',
	'Tables' => 'جداول',
	'Data' => 'معلومات',
	'Output' => 'إخراج',
	'open' => 'فتح',
	'save' => 'حفظ',
	'Format' => 'الصيغة',
	'Functions' => 'الدوال',
	'Aggregation' => 'تجميع',
	'Event has been dropped.' => 'تم مسح الحدث.',
	'Event has been altered.' => 'تم تعديل الحدث.',
	'Event has been created.' => 'تم إنشاء الحدث.',
	'Alter event' => 'تعديل حدث',
	'Create event' => 'إنشاء حدث',
	'Start' => 'إبدأ',
	'End' => 'إنهاء',
	'Every' => 'كل',
	'Status' => 'حالة',
	'On completion preserve' => 'حفظ عند الإنتهاء',
	'Events' => 'الأحداث',
	'Schedule' => 'مواعيد',
	'At given time' => 'في وقت محدد',
	'Save and continue edit' => 'إحفظ و واصل التعديل',
	'original' => 'الأصلي',
	'Tables have been truncated.' => 'تم قطع الجداول.',
	'Tables have been moved.' => 'تم نقل الجداول.',
	'Tables have been dropped.' => 'تم حذف الجداول.',
	'Tables and views' => 'الجداول و العروض',
	'Engine' => 'المحرك',
	'Collation' => 'ترتيب',
	'Data Length' => 'طول المعطيات.',
	'Index Length' => 'طول المؤشر.',
	'Data Free' => 'المساحة الحرة',
	'Rows' => 'الأسطر',
	',' => ',',
	'Analyze' => 'تحليل',
	'Optimize' => 'تحسين',
	'Check' => 'فحص',
	'Repair' => 'إصلاح',
	'Truncate' => 'قطع',
	'Move to other database' => 'نقل إلى قاعدة بيانات أخرى',
	'Move' => 'نقل',
	'%d item(s) have been affected.' => 'عدد العناصر المعدلة هو %d.',
	'whole result' => 'نتيجة كاملة',
	'Clone' => 'نسخ',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'لقد تجاوزت العدد الأقصى للحقول. يرجى الرفع من %s.',
	'Partition by' => 'مقسم بواسطة',
	'Partitions' => 'التقسيمات',
	'Partition name' => 'إسم التقسيم',
	'Values' => 'القيم',
	'%d row(s) have been imported.' => 'عدد الأسطر المستوردة هو %d.',
	'anywhere' => 'في اي مكان',
	'Import' => 'إستيراد',
	'Stop on error' => 'أوقف في حالة حدوث خطأ',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'jj/mm/[aaaa]',
	'History' => 'تاريخ',
	'Variables' => 'متغيرات',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'أعمدة المصدر و الهدف يجب أن تكون بنفس النوع, يجب أن يكون هناك مؤشر في أعمدة الهدف و البيانات المرجعية يجب ان تكون موجودة.',
	'Relations' => 'علاقات',
	'Run file' => 'نفذ الملف',
	'Clear' => 'مسح',
	'Maximum allowed file size is %sB.' => 'حجم الملف الأقصى هو %sB.',
	'Numbers' => 'أعداد',
	'Date and time' => 'التاريخ و الوقت',
	'Strings' => 'سلاسل',
	'Binary' => 'ثنائية',
	'Lists' => 'قوائم',
	'Editor' => 'المحرر',
	'E-mail' => 'البريد الإلكتروني',
	'From' => 'من',
	'Subject' => 'الموضوع',
	'Send' => 'إرسال',
	'%d e-mail(s) have been sent.' => 'تم إرسال %d رسالة.',
	'Webserver file %s' => 'ملف %s من خادم الويب',
	'File does not exist.' => 'الملف غير موجود.',
	'%d in total' => '%d في المجموع',
	'Permanent login' => 'تسجيل دخول دائم',
	'Databases have been dropped.' => 'تم حذف قواعد البيانات.',
	'Database has been dropped.' => 'تم حذف قاعدة البيانات.',
	'Search data in tables' => 'بحث في الجداول',
	'schema' => 'المخطط',
	'Schema' => 'المخطط',
	'Alter schema' => 'تعديل المخطط',
	'Create schema' => 'إنشاء مخطط',
	'Schema has been dropped.' => 'تم حذف المخطط.',
	'Schema has been created.' => 'تم إنشاء المخطط.',
	'Schema has been altered.' => 'تم تعديل المخطط.',
	'Sequences' => 'السلاسل',
	'Create sequence' => 'إنشاء سلسلة',
	'Alter sequence' => 'تعديل سلسلة',
	'Sequence has been dropped.' => 'تم حذف السلسلة.',
	'Sequence has been created.' => 'تم إنشاء السلسلة.',
	'Sequence has been altered.' => 'تم تعديل السلسلة.',
	'User types' => 'نوع المستخدم',
	'Create type' => 'إنشاء نوع',
	'Alter type' => 'تعديل نوع',
	'Type has been dropped.' => 'تم حذف النوع.',
	'Type has been created.' => 'تم إنشاء النوع.',
	'Use edit link to modify this value.' => 'إستعمل الرابط "تعديل" لتعديل هذه القيمة.',
	'last' => 'الأخيرة',
	'From server' => 'من الخادم',
	'System' => 'النظام',
	'Select data' => 'عرض البيانات',
	'Show structure' => 'عرض التركيبة',
	'empty' => 'فارغ',
	'Network' => 'شبكة',
	'Geometry' => 'هندسة',
	'File exists.' => 'الملف موجود.',
	'Attachments' => 'ملفات مرفقة.',
	'Item%s has been inserted.' => 'تم إدراج العنصر.',
	'now' => 'الآن',
	'%d query(s) executed OK.' => array('تم تنفيذ الإستعلام %d بنجاح.', 'تم تنفيذ الإستعلامات %d بنجاح.'),
	'Show only errors' => 'إعرض الأخطاء فقط',
	'Refresh' => 'تحديث',
	'Invalid schema.' => 'مخطط خاطئ.',
	'Please use one of the extensions %s.' => 'من فضلك إستعمل إحدى الإمتدادات: %s.',
	'ltr' => 'rtl',
	'Tables have been copied.' => 'تم نسخ الجداول.',
	'Copy' => 'نسخ',
	'Permanent link' => 'وصلة دائمة',
	'Edit all' => 'تعديل الكل',
	'HH:MM:SS' => 'HH:MM:SS',
);
